@@ -11,7 +11,7 @@
 #' }
 #' @export
 test_r <- function() {
-  purge_box_cache()
+  box::purge_cache()
   testthat::test_dir(fs::path("tests", "testthat"))
 }
 
